@@ -27,7 +27,7 @@ from string import Template
 import pyppyn
 from gravitybee.distutils_utils import fix_distutils
 
-__version__ = "0.1.66"
+__version__ = "0.1.70"
 EXIT_OKAY = 0
 EXIT_NOT_OKAY = 1
 FILE_DIR = ".gravitybee"
@@ -458,7 +458,7 @@ class PackageGenerator():
 
         # 1 - extra data
         hook += "# collection extra data, if any (using --extra-data option)"
-        for data in self.args.extra["data"]:
+        for data in self.args.extra.get("data", []):
             hook += "\ndatas.append(('"
             hook += self.args.directories["pkg"] + os.sep
             if self.args.directories["src"] != '.':
